#include "listIOint.hh" 

// Un elemento de una lista de naturales es "dominador" si es mayor o
// igual que la suma de los elementos anteriores a él.

// Queremos obtener el elemento dominador más avanzado una lista no
// vacía de naturales, i.e. el que está más lejos del inicio de la
// lista.

typedef list<int> Li;
typedef list<int>::iterator It;
typedef list<int>::const_iterator CIt;


int suma(const Li& t, CIt ite) {
/* Pre:  ite apunta a un elemento de t o a t.end() */
/* Post: El resultado es la suma de los elementos de t desde el
   comienzo hasta el elemento anterior al referenciado por ite. */
/* Coste: O(i), donde i numero de elementos de la sublista de t que comienza 
en t.begin() y termina en el elemento anterior al apuntado por ite. */
  int s = 0; 
  CIt it = t.begin();
  /* Coste del bucle: Si i = numero_de_elementos_de_sublista 
     [t.begin(), elemento anterior al apuntado por ite]
     sum_{k=1...i} O(1) = O(i), i.e. coste lineal en i. */ 
  while (it != ite) {
    s += *it; // Coste cuerpo del bucle constante, i.e. O(1)
    ++it;
  }
  return s; 
}


int dom(const Li& t) {
/* Pre:  t es una lista de naturales no vacía */
/* Post: el resultado es el elemento dominador más avanzado de t */
/* Cost: cuadrático en n, i.e. O(n^2) */
  CIt itd = t.begin();
  CIt it = t.begin(); 
  ++it; 
  /* Inv: itd apunta al elemento dominador más avanzado de t desde el
     comienzo al elemento anterior al apuntado por it */
  /* Coste while: Si n es el número de elementos de t, 
      sum_{i=1...n} O(i) = O(1+2+...+n) = O(n^2). */
  while (it != t.end()) {
    if (*it >= suma(t,it)) itd = it; // Coste cuerpo de while: O(i)
    ++it;
  }
  return *itd; 
}

// Cada llamada a dom(t) genera un número de sumas cuadrático con
// respecto a la longitud de t. 


int main() {
  Li v; 
  lee(v); 
  cout << dom(v) << endl; 
  esc(v); 
}
