#include "listIOint.hh" 

// Un elemento de una lista de naturales es "dominador" si es mayor o
// igual que la suma de los elementos anteriores a él.

// Queremos obtener el elemento dominador más avanzado una lista no
// vacía de naturales, i.e. el que está más lejos del inicio de la
// lista.

// Claramente no es necesario sumar todos los elementos anteriores al
// apuntado por it en cada iteración. Introducimos una variable local
// que almacena la suma de los elementos anteriores al apuntado por
// it, de manera que sólo sea necesario inicializar dicha variable y
// actualizarla en cada iteración. 

typedef list<int> Li;
typedef list<int>::iterator It;
typedef list<int>::const_iterator CIt;


int dom_ef(const Li& t) {
/* Pre:  t es una lista de naturales no vacía. */
/* Post: El resultado es el elemento dominador más avanzado de t. */
/* Coste: lineal en n, i.e. O(n), donde n es el número de elementos de t. */
  CIt itd = t.begin();
  CIt it = t.begin(); 
  int s = *it;
  ++it; 
  /* Inv: itd apunta al elemento dominador más avanzado de t desde el
     comienzo al elemento anterior al apuntado por it; s es la suma de
     los elementos de t desde el comienzo hasta el anterior al
     apuntado por it */
  // Coste del bucle: sum_{i=1...n} O(1) = O(n*1) = O(n)
  while (it != t.end()) {
    if (*it >= s) itd = it; // Coste cuerpo del bucle: O(1) 
    s += *it;
    ++it;
  }
  return *itd; 
}

// Cada llamada a dom(t) genera un número de sumas y operaciones en
// lineal con respecto a la longitud de t.


int main() {
  Li v; 
  lee(v); 
  cout << dom_ef(v) << endl; 
  esc(v); 
}
