#include <iostream>
using namespace std; 


// Mejoras de eficiencia en algoritmos iterativos

// Partimos de algoritmos iterativos correctos y naturales, e
// intentamos identificar y evitar cálculos innecesarios. 

// La estrategia consiste en utilizar los resultados de cada iteración
// para minimizar el coste de cálculo de la siguiente.

// Para lograrlo se introducen variables locales. Es muy importante
// que el valor de estas variables se especifique en la invariante
// para saber exactamente cómo inicializarlas y actualizarlas.


double pot(double a, int b) {
/* Pre: a > 0, b >= 0 */
/* Post: el resultado es a^b */
/* Cost: lineal en b, i.e. O(b) */
  double p = 1; 
  while (b > 0) {
    p *= a; 
    --b;
  }
  return p;
}


int fact(int n) {
/* Pre: n >= 0 */
/* Post: el resultado es n! */
/* Coste: lineal en n, i.e. O(n) */  
  int f = 1; 
  while (n > 0) {
    f *= n; 
    --n;
  }
  return f;
}


// Desarrollo de Taylor de e^x en el punto 0 hasta el término n-ésimo.

// La primera idea es generar cada término de la serie de Taylor en la
// correspondiente iteración sin aprovechar los cálculos de los
// términos anteriores.

double taylor_exp(double x, int n) 
/* Pre: n >= 0 */
/* Post: el resultado es la suma hasta el término n-ésimo de la serie
   de Taylor de e^x */
/* Cost: cuadrático en n, i.e. O(n^2) */
{
  double r;
  if (x == 0) r = 1; 
  else {
    r = 1; 
    int i = 1; 
    /* HI: r es la suma hasta el término (i-1)-ésimo de la serie de Taylor de e^x */
    // Coste bucle sum_{i=1...n} O(i) = O(1+2+...+n) = O(n^2) 
    while (i <= n) {
       r += pot(x,i)/fact(i); // Coste cuerpo del bucle O(i)+O(i) = O(max(i,i)) = O(i) 
       ++i; 
    }
  }
  return r;
}

// Cada llamada a taylor_exp(x,n) genera un número de productos
// cuadrático con respecto a n.

// Suma de serie aritmética: 1 + ... + n = (1+n)*n/2   

int main() {
  double x; 
  int n;
  cin >> x >> n;
  cout << taylor_exp(x,n) << endl; 
}
